import oss2
import requests
import os
import json
import traceback
import pandas as pd
from odps import ODPS
from log import Log
from config import set_config
log_ = Log()
config_ = set_config()


def get_data_from_odps(date, project, table, connect_timeout=3000, read_timeout=500000,
                       pool_maxsize=1000, pool_connections=1000):
    """
    从odps获取数据
    :param date: 日期 type-string '%Y%m%d'
    :param project: type-string
    :param table: 表名 type-string
    :param connect_timeout: 连接超时设置
    :param read_timeout: 读取超时设置
    :param pool_maxsize:
    :param pool_connections:
    :return: records
    """
    odps = ODPS(
        access_id=config_.ODPS_CONFIG['ACCESSID'],
        secret_access_key=config_.ODPS_CONFIG['ACCESSKEY'],
        project=project,
        endpoint=config_.ODPS_CONFIG['ENDPOINT'],
        connect_timeout=connect_timeout,
        read_timeout=read_timeout,
        pool_maxsize=pool_maxsize,
        pool_connections=pool_connections
    )
    records = odps.read_table(name=table, partition='dt=%s' % date)
    return records


def get_feature_data(project, table, dt, features):
    """获取特征数据"""
    records = get_data_from_odps(date=dt, project=project, table=table)
    feature_data = []
    for record in records:
        item = {}
        for feature_name in features:
            item[feature_name] = record[feature_name]
        feature_data.append(item)
    feature_df = pd.DataFrame(feature_data)
    return feature_df


def check_table_partition_exits(date, project, table, connect_timeout=3000, read_timeout=500000,
                                pool_maxsize=1000, pool_connections=1000):
    """
    判断表中是否存在这个分区
    :param date: 日期 type-string '%Y%m%d'
    :param project: type-string
    :param table: 表名 type-string
    :param connect_timeout: 连接超时设置
    :param read_timeout: 读取超时设置
    :param pool_maxsize:
    :param pool_connections:
    :return: records
    """
    odps = ODPS(
        access_id=config_.ODPS_CONFIG['ACCESSID'],
        secret_access_key=config_.ODPS_CONFIG['ACCESSKEY'],
        project=project,
        endpoint=config_.ODPS_CONFIG['ENDPOINT'],
        connect_timeout=connect_timeout,
        read_timeout=read_timeout,
        pool_maxsize=pool_maxsize,
        pool_connections=pool_connections
    )
    t = odps.get_table(name=table)
    return t.exist_partition(partition_spec=f'dt={date}')


def data_check(project, table, dt):
    """检查数据是否准备好"""
    odps = ODPS(
        access_id=config_.ODPS_CONFIG['ACCESSID'],
        secret_access_key=config_.ODPS_CONFIG['ACCESSKEY'],
        project=project,
        endpoint=config_.ODPS_CONFIG['ENDPOINT'],
        connect_timeout=3000,
        read_timeout=500000,
        pool_maxsize=1000,
        pool_connections=1000
    )

    try:
        check_res = check_table_partition_exits(date=dt, project=project, table=table)
        if check_res:
            sql = f'select * from {project}.{table} where dt = {dt}'
            with odps.execute_sql(sql=sql).open_reader() as reader:
                data_count = reader.count
        else:
            data_count = 0
    except Exception as e:
        data_count = 0
    return data_count


def request_post(request_url, headers, request_data):
    """
    post 请求 HTTP接口
    :param request_url: 接口URL
    :param headers: 请求头
    :param request_data: 请求参数
    :return: res_data json格式
    """
    try:
        response = requests.post(url=request_url, json=request_data, headers=headers)
        # print(response)
        if response.status_code == 200:
            res_data = json.loads(response.text)
            return res_data
        else:
            return None
    except Exception as e:
        log_.error('url: {}, exception: {}, traceback: {}'.format(request_url, e, traceback.format_exc()))
        return None


def request_get(request_url, headers, params=None):
    """
    get 请求 HTTP接口
    :param request_url: 接口URL
    :param headers: 请求头
    :param params: 请求参数
    :return: res_data json格式
    """
    try:
        response = requests.get(url=request_url, headers=headers, params=params)
        if response.status_code == 200:
            res_data = json.loads(response.text)
            return res_data
        else:
            return None
    except Exception as e:
        log_.error('url: {}, exception: {}, traceback: {}'.format(request_url, e, traceback.format_exc()))
        return None


def download_video(video_path, video_id, download_folder, ftype='mp4'):
    """下载视频"""
    if not os.path.exists(download_folder):
        os.makedirs(download_folder)
    filename = f"{download_folder}/{video_id}.{ftype}"
    # 视频已存在，则不重复下载
    if os.path.exists(filename):
        return filename
    response = requests.get(video_path, stream=True)
    if response.status_code == 200:
        with open(filename, "wb") as video_file:
            for chunk in response.iter_content(chunk_size=8192):
                video_file.write(chunk)
        return filename


def asr_validity_discrimination(text):
    """判断asr识别的文本是否有效"""
    if len(text) == 0:
        return False
    words = set(text)
    words_rate = len(words) / len(text)
    print(len(words), len(text), words_rate)
    if words_rate < 0.1:
        return False
    return True





if __name__ == '__main__':
    text = """现场和电视机前的观众朋友，大家晚上好。
这里是非常说明的访谈现场，
在我们的中国有这样一个非常了不起的一位科学家，毛泽东呢曾经半夜下指示，
要人要给他看病，
周恩来呢亲自
安排他的工作，
邓小平
要给他解决住房问题，
啊我们的领导人贾庆林
习近平同志
又安排他的修养，
这个人就是
中国科学界的一位了不起的
科学家数学家陈景润。
他曾经是我们全国老百姓的偶像，
过去人们总在
讲的是
陈景润的确是一个
天才般的数学家，
但同时老百姓也说了，
在生活中啊
说他挺傻的，
挺笨的。
但是他到底
是不是这传说中是这样的？
那么今天
我觉得非常的高兴，
能够请来的
这位嘉宾朋友可以说是最有发言权的一位朋友。
那么现在让我们掌声欢迎
陈景润的夫人
尤坤女士。
你好，大姐。
陈景瑞，
福建福州人，毕业于厦门大学数学系，
中国著名数学家。
1966年年仅33岁的陈景润证明了1+2为哥德巴赫猜想研究树立了里程碑。
1978年作家徐驰的报告文学哥德巴赫猜想，
令陈景润一夜之间成为了全民偶像。
游坤
1951年出生，
解放军总医院第二附属医院放射科主任，
1978年在武汉军区156医院任医生的尤坤，被单位派到北京的解放军309医院进修，认识了当时正在住院的陈景润。
1980年8月25日两人在北京结婚，婚后育有一子。
嗯
那您还一定会记得第一次见到陈景瑞那是什么时候？啊
78年。
78年那个时候的话，我是呃
在湖北嘛我原来在湖北派到北京来呃进修学习的年轻医生是这样，
呃我先生那个时候78年是到要到美国去讲学，
之前
要做一个查体，这样的话我们。
相遇了，当时您多大？啊
当时

27岁。吧
那您见到他的第一面的印象，
给没给您把您给镇住了？
有一个大数学家好像没有，我当时也是很好奇，
跟我们呃一起进修的嘛两个两个两个医生一起说，我们也去看一下。
好，结果我们就到了他病房去去的话，呢呃好像
呃先生很客气，
其实也就是打个招呼，后来我们就赶紧说呃您您您好好休息，吧我们我们走了。
就赶紧就跑掉了，那他最早怎么您感觉？唉
对，我有点意思啊还是什么的。
他住到呃高干病房，嘛我就去查房，
查房的话唉我先生就说
唉就问我是从哪里来的，我就告诉他是武汉来的。
后来呢他就说
嗯他说
那你
你爱人也是军人吗？
嘿你看看后来我说我说没有不是，我我说没有呃没有没有爱人还没有结婚，嘛是这样的。
完了以后他说那男朋友呢
我说男朋友也没有，因为那时候真的我那时候还是蛮要求上进那种的，啊整天学习啊干什么的，
好像也还没觉得自己大了，要谈恋爱啊什么的，好像也没有那种概念，也没有谈。
后来我说没有。
好。
他应该说这个可以有，他他没没没有反正就随便聊一下。
嘛后来的话呢就是呃也是查房的时候啊什么的，后来我先生就他天天吃面条你知道吧？
那个时候他做到刚开始刚开始还是蛮好的，
他可以自己点，
但是他的话每天好像就中午晚上都要吃面条，
后来我说你呃干嘛不点一点别的好吃的东西那么多，啊你点一下不就还是蛮方便的。
结果后来他说嗯面条容易消化，吃得也很快一下就吃掉了，嘛那意思就是说又省时间，
又很容易消化就够了。
后来我说呦那我我真烦死了，我说我不喜欢吃面，他说那你喜欢吃什么？我说我喜欢吃米饭，
一天三餐吃米饭都可以，每呃我我都喜欢。
后来当时他就说，
他说那太好了，你喜欢吃米，我喜欢吃面。
唉当时因为你知道就是那个米、啊面、啊粗粮、细粮啊
都要供应的，不是作品想买什么就买什么的。
所以他当时他这样说了一下，唉我当时好像也没太注意，我回去还跟我们的那个
一个同寝室的人讲，哈
唉我说残疾人真逗，
我说他说呃他说他喜欢吃面，我喜欢吃米，他说那就太好了，我说我吃米跟他有什么关系吗？
我们当时就这样笑话，就这样讲了一下就算了，我真的没有想那么多，没有想那么多。
那个时候我是呃
那个时候还是蛮爱学习的，嘛应该是这样讲，要不然也不会被呃单位派到北京来，那个时候能到北京来不得了的，
对不对？是这样的。
所以的话呢我那个时候就呃自己跟着那个拿半导体就那个小半导体
就是那个听那个广播英语广播，唉我那个时候是这样的，因为就呃每天查完房，
下完医嘱，
10:30我准时到我们病区，后边有一个大的阳台，
在那个地方我要听听半个小时的英语，
我在那学习的时候，他都要去晾晾晾些什么鞋子呀什么什么帽子呀什么这些东西，
但是我当时也没有那么多想，没没想过晾衣服的人很正常，嘛对不对？
后来的话呢有一天我先生就说，
你在学外语吗？
我说对。
他说我也在学，
我说不会，吧我就说我说你外语那么好的话你还要学，啊
他说要学，啊我每天都要学的。
后来他说他说
我们要是一起来学，吧
唉我说那不可以的，我说因为院里也有规定的，嘛就说不能去打扰他，他说没有关系的。
他说呃两个人学的话会
效果更好一点。
其实其实。
我当时我就想哈我我后来我说
我说这也不是没道理，哈这么好的老师在身边，那个时候找个老师很难的，后来我想如果要是有老师指引一下，自己会进步得更快一点。
哈
后来我说那好吧，
后来我们就从那以后的话，呢就是每天晚上7:30
学一个小时。
就一起在一起学习，嗯就这样，他主动邀您一起学外语，其实那个年代我们大家要印象的话，那个年代的人谈恋爱，哈
还真是以这个一起学习，呀
一起进步啊为理由，是不是用这种方法偷偷的接近他的目标？
是吧？你看你们都乐了，你们都这种方法谈的恋爱吗？
当时您就一点想法都没有啊没有。
想那么多，因为他我觉得他自己很爱学习。
有一天我先生就说，
如果我们要能永远在一起就好了。
唉呦唉呦你看看。
后来当时您唉呀我当时我就想红的不得了。
心慌的不得了，心慌的不得了了，因为真是太可怕了我我太可怕了，后来我当时我就说我
我我说这是不可能的，
我说简直你开国际玩笑，哈后来他他说啊对对对他说呃是是是我那个你你又年轻又漂亮啊什么，
呃也我我年纪又这么大，身体又不好，什么都都在自己在那嘟嘟囔囔的，我就把书一合，我说
我说那我我不学了，我说我我就回去了，
好，我拿不出我就走掉了，
走到了以后接着我就再没有去，有一天我说晚上我我在值班，我先生又过来了，他说尤医生你在值班，啊
我说对，我说没有事吗？
后来他说
嗯呃不不好意思，是我乱讲话，我还是请你一起学习呃学外语。
后来我说没有关系的，我说不学了不学了，没有关系的，我说不去打扰了。
但是我先生就
呃就就就特别像就是说。
越挫越勇。
那不你打击他太大了，太打击他了。
后来的话唉我我我先生不是主要我自己啊没没没有这种没有没有这种想法的，
后来他不是这样说，嘛我也觉得他挺诚心诚意的，
后来我说那好吧，我我我们又又开始学习，
嗯结果开始学习以后呢好，结果他说的话
差点给我累死了。
真的我跟你讲，结果他说
他说。
如果你
不跟我结婚的话，我这一辈子不会结婚的，
噢哇这句话太重太重了，而且他不是开玩笑的他不是开玩笑的人，
对吧？
而且他这么说了也肯定会这样做。
我我就想啊我说
如果他真的一辈子不结婚，
我就是以后跟别人结婚了，
我心里也是一一一种一辈子的愧疚，一辈子的愧疚，那也很难过的，太难过了，呃对。呀
后来我就说我说唉呀这么大的事，我说那总要
呃叫我好好想一想，
我说而且还要跟家里商量一下，
其实就说了这么多。
听说您也是特别聪明，
您就提的特别
几条特苛刻的条件，想把他给吓回去，实事求是，吧实事求是实事求是。
应该是这样的。
因为我这个人的话呢就说
很笨的，
真的很笨。
不会做饭，
啊呃不会做衣服，女孩子做的那些什么勾毛线啊什么就是打一些什么东西啊我都不会的。
而且的话呢最糟糕的一个就是脾气特别坏，
唉我真的脾气很坏很燥的那种。
不会做饭，不会做衣服，脾气还坏。
对，你受得了吗？看看后来我先生说。
没有关系的，他说不会做饭的话，我们可以吃食堂。
唉呦啊真好，太逗了陈主任，完了他说不会。
做衣服的话，
我就穿你的那个军装就可以了，所以你们刚才看到。
了就穿军装真的那个年代。
而且它是以军属为荣的，
你知道吧？就就穿着军装特别美。
脾气坏呢他怎么怎么应对的？
结果的话呢他说脾气不好，啊
他说那我们在一起就好了，
他说我比你大，而且我我不急的，
他说我会我会我不会跟你吵架的，
所以他这么一说的话，
唉呦你简直你你你有什么办法，反正我的缺点我都告诉你了，我没有隐瞒的对不对？结果他就这么轻轻松松就把你对付掉了。
这数学家情场老手，吧
人家跟我们过去的那种观念真不一样，
以为科学家数学家
好像挺死板的是吧？挺刻板的，啊你看看
你追女朋友多厉害，那认识多久就决定结婚了，结婚有什么盛大的仪式没有在那个。
没有两年以后吧认识两年之内，啊因为在这两年之中的话，呢我们到美国英国法国
去讲学了，嘛他去绕了一圈，两年后回来结婚，后来没有办什么仪式。
说实在的，我我们两个都不太想太张扬，
所以的话就没有没有办什么仪式，
后来就去买糖买了好多糖，
一样一点一样一点，每一样糖都要买一点，
各种花籽不一样的唉都都都放一起啊很漂亮的，价钱也不一样的，而且买的也不是说这个一斤那个一斤没有这样的这个八2那个万斤那个什么什么什么，
就买了很多嘛买糖的时候特别逗，
那个时候的话是没有计算器的，当然只有算盘算盘，因为我们买的也很杂，又多什么乱七八糟的你知道吧？
所以那个小伙子的话呢就在那噼里啪啦噼里啪啦一个一个给他看完了，一个个的算一笔笔记，后来他还没有算完我先生这个时候。
多少钱多少钱。
后来那小伙子就
瞪了他一眼，
就说
你以为你是陈景润的？
Haha哈哈那个。
时候为什么会因为的话是只有报纸上新闻呃那个广播里能能知道人的名字没有电视吗？那个时候对，啊所以他长什么样是不是？
知道的时候的分居很正常的，
特别是部队里边你知道吧？所以我们也没觉得我们要比别人特殊，要向组织提出我们要调到一起，
也不好意思，张这个口的后来的话呢还是就是呃
呃不知道怎么传到小平，
从他的耳朵里去了。
后来知道我们结婚三年多还在两地分居，那时候我儿子都已经
一两岁了，嘛83年的9月份
领导找我，
说你准备一个星期之内必须回北京报到，
说那个军区
就是打电话就是催的，说必须要一个星期之内幽魂必须回北京，
所以就这样写。
急了火的抱着我儿子拿着东西就回来了。
嗯就这样还真是邓小平唉对对就批下来了，特事特办。
唉那那个房子真的变大了。
当然大了，呀那个时候是院士房。
多少平米？啊那个140多。
那个时候80年代的话应该算大的了。
那当然不及房了。
如果没有小平批的话是不可能给我们不。
可能进去的，所以邓小平是爱才爱惜人才。
没有没有
小平同志的这种关心关心关关爱这种的哈就没有陈景润的今天。
是的。
嗯
那当时你们两位结婚那个时候工资有多少，家里谁管钱呢？
应该说谁花钱。
吧唉呦这话怎么讲啊大姐，
但实际上那个时候钱。
的话倒不是很多，
我们两个应该是加一块，
是
300多，
啊那个最早的时候是89块钱的时候，小平同志就说
为什么不能给他多补助一点，呢身体不好嘛可以再补充营养啊什么的，就给他特批了50块钱。
七几年的时候就那时候很多的了，家里的钱呢应该说是呃先生的钱要存一点，
他每个月要存一点，剩下的就呃放到我这里，那么我的工资的话那肯定是月月光
全花掉，月光族那会儿唉月光族，对那个时候不是做完了，嘛
我就跑出去了，买了一大堆的东西回来。
因为原来花钱的话，我先生他不说我的，但是这次的话他一看我买了一大堆，结果回来
他说有啊
他说你不能这样呃大手大脚的，
我们要存些钱的，
我我说为什么？
结果他说
呃小欢欢以后上大学要自费的，
后来我说你瞎说，对，呀我说不可能，
结果他说你不信算了，你到时候看，
你看哇我特别奇怪，
等到真是自费的时候，我就等于是要孩子上大学要自费，家长要出钱的时候，我就想唉呦他怎么会知道。
啊对呀那时候好奇怪，20多年前的预测他就准了，特别逗我跟你讲。
有时候的话我呃到月末了啊没有钱了，嘛那我肯定就不出去了，后来的话呢我先生就跟我儿子说，
小欢欢
妈妈今天没有上街去，肯定是妈妈兜里没有钱了。
他太了解我了，我跟你讲他用这种方法旁敲侧击告诉你，唉这不要话多了啊少花点了，别逛去了。
听说就陈景润就特别会过，连剪头发理发都不出去，都在家是吧？
唉那不是为了省钱的，噢呃他是为了省时间。
噢省时间省。
时间那个时候大家可能都知道，啊也就是说呃理发馆比较少，
理发的人还蛮多，每次理发的话可能要排半天那样的，他是惜时如命的人，他尽管坐那看书，他也觉得耽误他很多事。
后来我就跟他说，
我说这样，吧
我说我我我给你理，
他说呀太好了太好了，
我就
跑到街上去就买了一个那个
就是手动的那种推子，就嘎嘎嘎那种推子，我没想到那么难，啊我我我
我可能高估自己了，结果上去一下子
夹上去了，下不来了，唉呀
唉呀急死我了，我说这怎么办？一栋很疼的，后来我就问我先生，我说疼不疼？
还可以还可以，其实应该是很疼的对吧？那加到了上面
就怎么都下不来，最后没办法，我就拿剪刀把那撮毛给解释了。
嗯
唉呀就这样，反正哪下不来就捡一下子，完了要不然就总算把那个头理完了。
小时候的话叫什么像狗啃的似的。
唉呀狗啃的一点都不错，我跟你讲忒难看了，天上到所里去，啊
后来别人一看，
唉呀陈教授你那个头在哪理的，呀后来怎么理成那个样子啊怎么理成这个样子？
后来我先生说
是在一个很小的理发店里的，人特别少去了就理，唉呀后来我说唉呀太好了，我说你没有说我理的，
他说我不能说是有理的说了他们会笑话你的。
后来第二次的时候，
唉呀我说你还敢让我理吗？
没有关系的，有顶聪明一学就会的，你会慢慢就会学好的，从那以后
一直到先生去世，
都是您都是我来给理发。
都是我来理，就包括刚刚这些照片什么都是我理的，后来包括我儿子，
所以两个人是一样的头发，后来的话我儿子长大了，上了中学以后。
就不让我理了，因为太难看了，只会理这种东西，不会的。
啊
他每次我做什么不管什么样，他都说挺好挺好的，那家里来客人呢您瞎做最拿手的菜是什么？呀
那个时候刚结婚的时候，正好他们呃福建的一个朋友
到北京来出差，正好中午我赶上吃饭了，嘛北京那个大茄子有这么大个，
好像一块钱三个，吧
好像是这样的。
结果就买回来了。
当西瓜吃给他哪里没有。
结果我就把那一个茄子全都给人家
烧了，就烧了一锅，结果最后呢盘子根本就装不下。
我不知道大家记不记得，就是原来有一种放那个暖瓶，
4个茶碗放在一起的那种大铁盘子，
结果我就把这个盘子洗干净了以后，就把那个大茄子烧好了以后就算一个菜，
就是我炒鸡蛋一个菜，我先生还砸了一个虾片，我们两个在那瞎忙活，嘛总算是给人家就是端上了几个盘总算端上了个盘，哈结果给人家吃了。
后来呢吃完了以后，那个那个朋友也没有说什么，
嗯结果呢后来是啊我调来北京以后，那个时候我儿子好像都都快上小学了，吧
结果这个朋友又来了，
我就特别谢谢，那个啊就想叫他看一看我的现在的手艺。
啊
就
煮了一大桌，吃完了饭以后，这个朋友说
唉呀有可能
他说我现在可以说了，
他说你记得我当年在你们家吃的一餐饭，吧
他说。
甭提有多难吃了。
那我先生说有捆顶聪明的，他就反正有任何机会他都要表扬我。
一下子夸我一下子。
他说有很顶聪明的，什么现在就学什么都会的。
是的，他怕你老喂他吃茄子呀害怕，呀那么我们知道这个陈景润啊他还要您帮着他这个
刷牙洗澡。
因为我先生啊他就是说呃你比方说早上洗脸，啊
它能多快它就多快，我跟你讲就那个水一标，
插一下子就完了，
你知道吧？
就糊弄人，啊就这样的刷牙的话也是咚咚咚蹭两下就完了。
如果我在家的话，我一定要帮他好好洗一下，因为你洗干净以后人也很舒服，嘛对吧？
而且帮他做的时候呢我跟你讲，
他特别开心你知道吧？有时候我还说他两句，嘛
我把嘴张大点什么是怎么样怎么样的，哈到到他脸上就扑下一喷牙膏全都喷到那个镜子上哇就更开心了，更更笑得不得了，他很开心。
所以后来是包括他洗脚啊什么洗澡，啊
都是我来帮他做，太会享受了，都是我来帮他做，因为这样做的时候呢他也很开心，而且我帮他做的话
又可以省时间，而且他也很舒服。
谢谢谢谢婚后啊
婚后的男人一般都不爱说甜蜜的话了，
反正把你搞到手了，嘛都是我媳妇了。
呃可以这样讲，吧就是说我先生他很用心很用心，
他也很在乎我的感受，属于这样的，他也要去呃跟我去陪我去逛街。
对。
你们都想象不出来他会怎么去跟你逛是。啊
他这样的话他说要去呃有啊我们去呃呃我陪你去逛逛街，吧
我说你有时间吗？他说有的有的，
我说那好吧，
后来他说但是的话你要把你兜里的钱都要掏出来。
噢我说逛街。
去不拿钱去干什么，啊后来他说。
亚马洛喝西北风去。
啊他说我们今天去我带你去，就是在一样的时间内
就可以跑很多很多地方，就是光看不买，
这样可以省时间。
这就是太会过了。
可以省时间啊可以省出好多，嘛因为你要买的话你要问一下子啊或者怎么样啊什么什么，这要耽误时间的。
他说反正你在休假，你到时候明天自己再来买，唉呀我说你没时间就算了，我说我不是说非要你陪我或者怎么样的，啊他说那不行，我一定要陪你去，
我还没有办法，所以每次上街的话兜里钱必须掏出来。
按照现代人的理念认为
是陈景润
应该算是好男人，
对吧？
能赚钱，
但是不爱花钱，
还会甜言蜜语，处处让着您。
这么好的男人其实
应该是很抢手的，先生确实是有这么多优点。
但是你没有跟他一起生活的人是不会发现他的亮点，
找他的人很多，而且有很多是比我优秀的。
我很平常嘛对吧？
您太不平常了，不会做饭。
不会做衣服，啊还脾气大，您太不平常了。
所以的话呃先生说呃他都他都给人的回答，都说我我不想谈恋爱，
所以在我之前
他没有谈过恋爱，我是他第一个恋人，第一个爱人也是守护他一生的人。
嗯
他跟您讲过没有，他在文革当中的一些经历啊的话。
就是从58年我想可能老同志都知道，
那个时候科学界的话就是在
拔白旗，
白白旗事业所的话，呢大白旗呢就是
华老了，华罗庚，那么小白旗那肯定是陈景润的。
后来60年的时候呢就是先生就被
赶出北京，
到大连化学所
去劳动改造，
两年多的时间，
但是在这两年中，
现在是先生人生中的一段空白，
因为先生回来的时候问他
在那里怎么样，
他都是摇摇头，一个字都没有讲过，后来的话呢还是华老就是跟那个总理汇报了陈其润的情况，
因为他很可惜觉得非常可惜的这么个人，那个时候总理就停了以后亲自来
把这个陈主任第二次调回了宿舍宿舍，
而且在9呃74年的时候，总理亲自推荐，
陈景认为人大代表还跟总理一个小组，
在这一个小组的时候，呢就是总理就拍到景润的肩膀，啊
就说你一定要学好外语。
所以先生我跟你讲，后来的话真是玩命的学外语，他学了6国外语，
所以说大家都知道那个毛主席语录，
毛主席语录也有英文版的，
他有时候他就把那个
字典啊或者什么东西夹到里面，背点单词也是好的，嘛对吧？是夹在毛主席语录里，因为他胆子大。啊
文化大革命那个时候4人帮就想利用陈景润来揭发批判
小平同志的，就是说如何让他走白钻道路的，后来我先生无论他怎么说都没有答应，
都说我没有见过邓副主席，我也没有听他说过这些话，
所以人家气得要命，
那都是人人自慰的时候，那那么
没有人敢去这么大的胆量去犯上的。
所以先生他做到了，
所以他不会做做违背自己良心的事。就是
但是我知道他内心呢也承受着一种巨大的一种压力，
委屈。
因为
文革期间
是陈景润
有过一次自杀吗？
对，他那那次跳楼的时候是从三楼上跳的，原来的那个三楼楼层很高的很高的，他正好在
工作的时候，嘛
那个时候的研究啊我跟你讲都是偷偷的一伙子人就
冲进来了，
冲进来了以后一看他那个屋里面到处都是稿子，
说你还在搞死人的东西，你还在搞洋人的东西，你这是封资修，
这就是罪证，你想复辟吗？
先生就当然要护着他的稿子了，就趴到那个上面这些人就
拳打脚踢的，根本不管你是皮头啊还是脚的，这样就使劲打，结果有一个人的话呢是拿到就是油布的那个
雨伞，
居然把那个伞都抽烂了。
大先生，嗯所以但是的话呢
那也护不住的，
一瞬间就全都给毁于一旦。
那是先生几年的心血，呀稿子草稿嘛就是1+2那个草稿，后来还有一个人就讲
收拾他给他搜身，就这样的。
一搜的话就把先生多年的积蓄，
还有他妈妈留下来，因为他妈妈早就去世就去世了，嘛就是给孩子们留下来的那个金戒指吧还是什么东西啊全都给收走了，
结果的话先生就真的绝望了，
他想以此来抗争，
所以他就冲出去了。
正好就是也是他那个6平方米的小屋嘛跑到走廊尽头那个地方，从那个窗户就跳下去了。
跳下去了以后，好，幸亏我跟你讲就说有一棵大树一个
支正好搭到那个窗，那个地方离得不远，嘛
它往下种的时候就能跳的时候唉硌了一下，硌了一下，有个缓冲。
嘛
这样的话呢先生就
大难不死了，但是造反派登从楼梯上跑下来以后出来，
一看唉残疾人没有死，而且好像也无大碍那样的，啊就是擦破了那个皮嘛皮外伤。
嘛
他们说
他不会是数学家，
跳楼都要算好角度，
啊特别恶劣唉特别恶劣，完了以后一顿拳拳打脚踢说你这是在
呃那个就是吓唬革命群众，
呃是在与人民为敌，
又是个罪名，又给打了一局得够呛给给抓起来。
造反派给他做了一个
大牌子，上面写到呃这个白子恩典席，
呃那个寄生虫。
白痴。
完了陈景润三个字拿大叉子一叉
擦掉。
所以的话呢就是说只要他走出6平方米，
必须带这个牌子，包括去吃饭，
所以有时候一饿的话都两三天都不能吃东西，
所以实在没有办法了，才带着这个牌子去吃饭。
所以可想而知他受的是什么样的待遇，噢那个在减药了吗？那个时候应该说在世界数学界
引起了一些轰动，当时好像有一个外国代表团到了那个北京来访问，嘛
后来就说想见一下这个人那肯定是不可能的，他已经是牛鬼蛇神，这给给
挨批斗的嘛怎么会让这样
后来就把这个事情
就写了内参，就说
中国有一个人
就是做出了一个重要成果，引起世界的反响。
后来呢就说这个人现在
患重病，
生命危在旦夕。
主席看了以后就说
唉呀就特别着急那样的，啊就马上写下三个字，要抢救，还画了一个圈，
画了一个圈。
那个时候大家都知道，落实毛主席指示的话是不能过夜的，
啊不能等到第二天你再怎么样，你半夜说的你半夜就得去执行。
后来领了一行呃一一行人就跑到数学所叫，到了数学所的领导，
好一起就去。
到了先生住的6平方米，先生吓死掉了，一想肯定又来抄家来了，赶紧在里边就就就怎么都不开门，就该藏的藏该掖的掖，你吓坏了吓坏了，你知道吓坏了。
后来的话呢外边呃武峰同志讲，就是说我们是毛主席派派人来看你的，
先生一想这下更懵了，怎么会毛主席知道我陈景润啊这肯定是假的了，来骗他开门的你知道吧？
所以就越发不开门。
最后还是所里的领导就使劲叫他还是把这个事情说明白了，
他才算把门开开了，
开开了以后呢好大家就赶紧就把他给带走了，
就带走了。
一下就开到了这个清华大学，协和医院的内科专家已经在那里等等着了，
做了很仔细的这种体检，
最后就说呢说有病。
是是没错有病，
但是不至于说
危在旦夕，吧
就说不至于那么严重。
说到那个呃疗养院去疗养一段时间就会好些了，
但是先生死活死活都不肯去做，
因为他知道那个时候到医院里去的话，那众目睽睽之下，
他没有办法研究工作了，要影响他工作的。
尽管遭遇了这么多事情，但是我先生从来没有从他嘴里说出一句抱怨的话，
八几年的时候八几年的时候就说那个那时候我们已经调来了嘛
呃原来数学所的一个人，
就是当然他自己是不会好意思来的，
叫叫他的家人过来就说找到我先生，
就说要推荐他到国外去留学深造，
那么我先生就
就给写了这个推荐信，
这个人的话呢也如愿以偿地出国去留学了。
那么后来手里的人跟我讲，
是游大夫，你知道这个人他是什么人，对。
他说
陈先生给谁写推荐信，
都不能给这个人写。
我说为什么？
他说这个人我跟你讲在文化大革命的时候，
对先生大打出手，
而且
特别恶劣。嗯
他说是这样的人怎么会有这样的
给他写。呢
唉呀我当时气死掉了，我跟你讲真的气死掉了。
我说你为什么要帮这种人？
后来这个先生
特别平静，出乎我的那那那种特别平静，
他说一切都过去了，
不要那么想那么多了。
他说他现在出国去留学深造，
以后他回国了，
他会做更多的事就好了，我我我当时我我真的是无语了，
我真的是无语了。
后来我就想也许就是
真正一个学者的胸怀吧只能这样去理解，是这样的。嗯
对。
我我作业的时候所有的
吃喝用
全他全在我身上，一天要跑好几趟，那时候又特别冷，最糟糕的是我没有奶，我儿子又特别能吃，
所以的话呢我先生就急的不了，听人家说什么猪蹄少奶，
他就跑去屠宰场，
那师傅特别好，
结果就一下子卖了，我先生就是说十几斤的猪蹄
高兴得不得了，他以为有了猪蹄就来了，他以为有了猪蹄就有了买，其实哪那么简单，啊哪那么那个的
结果的话呢吃了好多猪蹄还是没有奶，我自己长了二三十斤肉。
对对对。
而且他净净那种
那个点子你知道吧？他就怕我这个这个
呃睡着了以后把儿子怎么碰着了或者怎么着的，啊什么拿一个大被子褥子什么垫垫高，儿子要比我们的床高出那么多，把孩子放上头。
啊太逗了，常景润。
跟您
说过吗？
比如说唉
要儿子。啊
后来来个女儿也行，我们好像怀孕的时候也也都聊过，嘛就是你喜欢我我就问他，我说你喜欢儿子还是喜欢女儿啊什么的？
他说儿子女儿都喜欢都喜欢，他等生完儿子以后我们聊天，啊
后来他就说，
其实你一下火车的时候，我就知道你可能会生儿子，
唉我说你怎么知道？他说人家告诉他
吃米就看游坤，
是比原来漂亮了，还是比原来丑了？
说如果要是走了的话，呢就是生儿子的几率就大一点，就说就走，结果他说
一下火车我就发现
你比原来丑多了，像像老大娘一样还不说就满脸都是那个那个就是长的那个黑斑，啊
后来我说唉好像没有听你说过，
他说那不能说的，说了以后会有压力的，嗯对。
但是他心里真的好逗，啊跟你斗对。
我跟你讲他他惯儿子，我跟你讲比我惯的都多了，我跟你讲，
我这么大的脾气，我跟你讲我儿子我是吼过他，但是的话我我我我就是吼他的话说，他我儿子我先生都特别不好。
唉他都讲他说。
有啊你不能这种态度对孩子要说服教育，
啊我有时候气得不得了，因为我儿子他就是有个坏毛病，破坏性特别大，什么东西都搞坏，包括我先生用的那个计算器，后来就和那个
手风琴的样子差不多，但是扁着放的那种上面也有那个按键啊什么的，结果我先生居然不是我儿子居然把那玩意都抠出来，把那个里面的那个字母给抠出来，
唉他也不生气，我就使劲吼他，嘛就就说他什么的，我先生就说小欢欢在动脑筋，你不要这个样子的，他特别有耐心。
包括我儿子就说上呃上幼儿园之前三岁之前，嘛
他可以说很多外语就是说单词量的话应该有200多个
啊他都是他来教的，唉对，后来那个时候儿子要上学了，
结果他就有一天他就很郑重其事的来跟我说，
他说有啊他说我想
不让小朋友去上学，
我说那怎么行啊不上学去干嘛去。
后来结果我先生说我想自己削他，
嘿唉呦我说不可以的我说绝对不可以，我说孩子必须融入社会，
结果他说那好吧。
好，结果孩子照常上学了，那孩子后来呃从事什么专业，是不是他所期盼的？
我怀孕的时候的话呢先生就讲，
他说如果生男孩的话最好搞数学，
如果生女孩的话最好搞医，因为我是医生，嘛但是儿子
好像
不肯学的，小时候绝对不肯学的，他直到高中他都是学的文科。
结果出国以后的话，呢突然有一天
我儿子跟我说，妈妈他说我想转系，
噢我说你转什么学，因为原来学的是那个国际商务，嘛他说我想转数学系，
哇我说你不要
不要开玩笑，吧你是在逗我，吧
我说老妈可经不住你们这么一一次次的雷，我啊我告诉你，好，结果的话呢我儿子说不是的，妈妈他说这个我已经想了很久了，
他说一个是我越来越喜欢，再一个的话呢是那个呃就是
我
想圆爸爸的一个梦，
结果他就转到数学系，现在是数学系的研究生。
哈哈哈。
之后
其实谁看见了以后都都会心疼的不得了。
因为两种，一种的话呢是抖的那种，我先生是强直性的，
就他这个这边这一边幸亏是左手嘛左边还好，右手他不耽误他干事，嘛所以那么多年
先生就没有停止过工作，
一紧张的时候整个都较劲，最后最严重的时候包括吞咽，那个所有肌肉
都失去了控制。
就
啊就都属于这样的状态。
所以他牙也是这样咬着你知道吧，最后把那个下边的牙牙床全都咬咬倒进去了。
吃饭我跟你讲是最痛苦的事，
他自己也痛苦，
胃的人也特别的
难过难过，那个时候喂一次饭，
要一个多小时，
你要把它先撬开。
完了以后再倒开。啊
拉筷子啊软的那个那个那个呃压舌板啊什么东西的。
喂他的时候的话说实在的经常我都是。
泪流满面，我能感受到您对他那份心疼吗？
84年的时候，嘛呃先生祝愿在中日友好，祝愿
呃我们单位的就等于是总后领导，
嗯就跟我们院也都都讲讲了，嘛就说叫尤坤的话，
保留军籍，
呃就是晋级不耽误，就是说该调什么级就调什么级，这样的
呃就完全回家去照顾。
陈主任。
我当时的话
我是
非常愿意的，说实在的，因为我想到尽管我也是很上进的很那个的，
但是我比起我先生来讲的话，
我不重要，我要把我先生照顾好的话，这是
最重要的事情了，所以我特别高兴我就啊千恩万谢的应该是这样的，我就跑到中日友好，我我我先生看见我就特别高兴，
每次看见我都说油来了油来了，特别高兴的过了一会儿，
噢你今天怎么会来，呢又不是今天又不是你下夜班，
现在怎么会来？
呢
后来我就说唉呦我说告诉你一个好消息，
我说我们领导找我谈话说我可以不上班了，就天天来照顾你，
噢他一下子好像就不不讲话了，
就摘了一下，
带了一下我说怎么啦
他说不可以这样做的。
我说为什么？啊
结果他说呃这样不好的这样不好的，
他说你是部队培养出来的，
不能为我一个人服务，
他马上赶我走，非得叫我现在就走。
让你现在回去上班去，啊对，非得让我回去，特别特别牛的，我跟你讲特特别物质的，
我说我这样好不好？
我说今天我就在这里，明天我再去上班，
不行不行的绝对不行，后来我一看我也不想惹他生气，我我就走了，那个时候当时我是真是想不通的，
我说怎么会这样的？
哈
但是我先生走了以后，
我在想这一段，
我非常感谢我先生，
因为我先生他太了解我了，
他知道我也是一个很要强的人，
如果要是在家的话，我那个时候就是一个住院医生嘛就初级职称的。
嘛
如果先生走了以后，我就是个家庭妇女，什么都不是了，人家给你再高级别有什么用，
对不对？你什么都不会，
你自己怎么过？
而且的话如果我什么都不是的话，
我怎么来教育孩子，我怎么去
就是来
培养孩子。
所以先让他想得非常多，我跟你讲。
现在我走到我现在，
我应该说是在我业务上到各方面，
我那个时候我是想如果我做不好的话，
我对不起我先生。
没有是吧？
陈院士
走的时候，
您在不在身边？
先生是3月19号
13:10离开我们的，
结果那一上午都是我和儿子陪到我先生，
当时先生已经不能讲话，
我就跟他讲，我说你
如果同意我的说话的意思，或者是
你懂了你就伸一个手指头，
他还可以这样试一下，嘛我说你要是不同意或者是
不懂，你就分两个字我知道。
所以最后的时候，呢
我看他的嘴在动，
后来我就说，
我说我知道，
我说你放心先生，
我说我你是觉得小欢欢太小，
我说你放心，我会把儿子培养成人。
我说无论多大的困难，
我说我都会把它一定会
让他上大学
接受好的教育。
后来我说你听懂了吗？
先生伸出了一个手指头，
所以这也是先生对我的嘱托，
也是我对先生的承诺。
生死离别那一刻，其实对于人生而言的太难了太难了太难了，我能想象我也能知道
内心的那种
悲伤。啊
我觉得这么多年您看您谈到
先生离去的时候仍然是泪流满面，那是您一生的最爱了。
先生走了以后，有些
人跟我说，哈说你看
你你也不要太过于难过啊或者怎么样的，
他说你看你要不然的话，你要再这么折腾几年的话，只怕你可能也承受不起了。
我说真的不要，我不喜欢听这样的话，
我说我宁愿我先生，
哪怕他有一口气，
我每天我去照顾他，再辛苦再累，我说我都心甘情愿。
那那个我们家是一个圆满的家，
那么先生先生不在了，那么半边天塌掉了，我跟先生
走过了这一生，
没有过够，
如果有来生的话，我还会嫁给他。
他还是。"""
    res = asr_validity_discrimination(text=text)
    print(res)

